%  Calcula el parmetro t del punto ms cercano a la ellipse (a,b)
% en el origen, segun la distancia euclidieana de la elipse 
% al punto (x,y)
% El punto sobre la elipse se puede calcular como
%
% x = a*cos(l);
% y = b*sin(l);
function l = dEuclidean( a, b, x0, y0 ) 

	l0 = sqrt(x0*x0 + y0*y0);
	if ( l0 < 1e-6 ) 
		1 = 3.141592654/2; 
		return; 
	end
	v = a*a - b*b;
	if( abs(y0) < b && abs(x0) <= v/a ) 
		if ( abs(y0) < 1e-6 ) 
			l0 = 3.141592654/2; 
		elseif
			p = abs(x0)/(1 + abs(y0)/l0);
			if( x0 < 0 )
				p = -p;
			end
			l0 = atan2( a*y0, b*(x0-p) );
		end
	else 
		l0 = atan2( a*y0, b*x0 );
	end
		
	v1 = y0*b;
	v2 = x0*a;
	for i=0:3
		s = sin(l0);
		c = cos(l0);	
		f = v1*c - v2*s + v*c*s;
		df = -v1*s - v2*c + v*(c*c-s*s);

		if ( abs(df) < 1e-8 )  
			print "# NO $x0 $y0\n";
			l = l0;
			return;
		end
   
		l1 = l0 - f/df;

		if ( abs(l1-l0)< 0.00001 )
			l = l1;
			return;
		end
		
		l0 = l1;
	end
	l = l1;
	return;
end
